jQuery UI Menu - Contextmenu demo

- Amsterdam
- Anaheim
- Cologne
- Frankfurt
- Magdeburg
- Munich
- Utrecht
- Zurich

A simple contextmenu: Click the button, or tab to it and hit space to open the menu. Use the mouse or cursor keys to select an item, click it or hit enter to select it.

The keyboard handling is part of the menu. Using the input option to menu is configured to add the key event handlers to the button, as that button gets focused when clicked.